@@ -9,9 +9,9 @@ use Log::ger;
 use List::Util qw(shuffle);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-10-21'; # DATE
+our $DATE = '2021-10-24'; # DATE
 our $DIST = 'App-wordlist'; # DIST
-our $VERSION = '0.280'; # VERSION
+our $VERSION = '0.281'; # VERSION
 
 our %SPEC;
 
@@ -293,6 +293,12 @@ _
             test => 0,
             'x.doc.show_result' => 0,
         },
+        {
+            argv => ['-w', 'MetaSyntactic=theme,dangdut'],
+            summary => 'Select a wordlist with parameters',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
         {
             argv => [qw/-l/],
             summary => 'List installed wordlist modules',
@@ -562,7 +568,7 @@ App::wordlist - Grep words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.280 of App::wordlist (from Perl distribution App-wordlist), released on 2021-10-21.
+This document describes version 0.281 of App::wordlist (from Perl distribution App-wordlist), released on 2021-10-24.
 
 =head1 SYNOPSIS
 
@@ -633,6 +639,10 @@ Examples:
 
  wordlist(arg => ["/fof[aeiou]/"]);
 
+=item * Select a wordlist with parameters:
+
+ wordlist(wordlists => ["MetaSyntactic=theme,dangdut"]);
+
 =item * List installed wordlist modules:
 
  wordlist(action => "list_installed");
